from distutils.core import setup
setup(name='bein-htminilims',
      version='1.06',
      url='http://madhadron.com/bein',
      description='Web frontend to the MiniLIMS from bein',
      author='Fred Ross',
      author_email='madhadron@gmail.com',
      packages=['bein_htminilims'],
      scripts=['htminilims'],
      classifiers=['Topic :: System :: Shells', 'Topic :: Scientific/Engineering :: Bio-Informatics'],
      install_requires = ['cherrypy', 'mako'],
      )
